/*******************************************************************************
 * Copyright (c) 2005, 2006 Eclipse Foundation
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Bjorn Freeman-Benson - initial implementation
 *     Ward Cunningham - initial implementation
 *******************************************************************************/

package org.eclipse.eclipsemonkey;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;

import org.eclipse.core.resources.IResourceChangeEvent;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.ui.IStartup;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;

/**
 * The main plugin class to be used in the desktop.
 */
public class EclipseMonkeyPlugin extends AbstractUIPlugin implements IStartup {
	public static final String PUBLISH_BEFORE_MARKER = "--- Came wiffling through the eclipsey wood ---";

	public static final String PUBLISH_AFTER_MARKER = "--- And burbled as it ran! ---";

	// The shared instance.
	private static EclipseMonkeyPlugin plugin;

	private Map scriptStore = new HashMap();
	private Set storeListeners = new HashSet();

	public Map getScriptStore() {
		return scriptStore;
	}

	private Map scopeStore = new HashMap();

	public Map getScopeStore() {
		return scopeStore;
	}

	public EclipseMonkeyPlugin() {
		plugin = this;
	}

	/**
	 * This method is called upon plug-in activation
	 */
	public void start(BundleContext context) throws Exception {
		super.start(context);
	}

	/**
	 * This method is called when the plug-in is stopped
	 */
	public void stop(BundleContext context) throws Exception {
		super.stop(context);
		plugin = null;
	}

	/**
	 * Returns the shared instance.
	 */
	public static EclipseMonkeyPlugin getDefault() {
		return plugin;
	}

	public static ImageDescriptor getImageDescriptor(String path) {
		return AbstractUIPlugin.imageDescriptorFromPlugin(
				"EclipsemonkeyAction", path);
	}

	public void earlyStartup() {
		UpdateMonkeyActionsResourceChangeListener listener = new UpdateMonkeyActionsResourceChangeListener();
		ResourcesPlugin.getWorkspace().addResourceChangeListener(listener,
				IResourceChangeEvent.POST_CHANGE);
		listener.rescanAllFiles();
		UpdateMonkeyActionsResourceChangeListener.createTheMonkeyMenu();
	}

	public void addScript(String name, StoredScript script) {
		/* we are using the full file path as the key into the store
		 * the consequence is that renames or moves are considered deletes and adds
		 * is this what we want?
		 */
		Map store = getScriptStore();
		StoredScript oldScript = (StoredScript)store.get(name);
		if (oldScript != null) {
			oldScript.metadata.unsubscribe();
		}
		store.put(name, script);
		script.metadata.subscribe();
		this.notifyScriptsChanged();
	}

	public void removeScript(String name) {
		Map store = getScriptStore();
		StoredScript oldScript = (StoredScript)store.remove(name);
		if (oldScript == null) return;
		oldScript.metadata.unsubscribe();
		this.notifyScriptsChanged();
	}

	public void clearScripts() {
		for (Iterator iter = getScriptStore().values().iterator(); iter.hasNext();) {
			StoredScript script = (StoredScript) iter.next();
			script.metadata.unsubscribe();
		}
		getScriptStore().clear();
		this.notifyScriptsChanged();
	}

	public void notifyScriptsChanged() {
		for (Iterator iter = storeListeners.iterator(); iter.hasNext();) {
			IScriptStoreListener element = (IScriptStoreListener) iter.next();
			element.storeChanged();
		}
	}

	public void addScriptStoreListener( IScriptStoreListener listener ) {
		storeListeners.add(listener);
	}
	public void removeScriptStoreListener( IScriptStoreListener listener ) {
		storeListeners.remove(listener);
	}
}
