/*******************************************************************************
 * Copyright (c) 2005 Eclipse Foundation
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Bjorn Freeman-Benson - initial implementation
 *     Ward Cunningham - initial implementation
 *******************************************************************************/

package org.eclipse.eclipsemonkey;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.eclipse.core.resources.IFile;

public class ScriptMetadata {

	private IFile file;

	private String menuName;
	private String scopeName;

	public void setMenuName(String string) {
		this.menuName = string;
	}

	public void setFile(IFile file) {
		this.file = file;
	}

	public IFile getFile() {
		return file;
	}

	public String getMenuName() {
		return menuName;
	}
	
	public String getScopeName() {
		return scopeName;
	}
	public void setScopeName(String s) {
		scopeName = s;
	}

	public String getReasonableFilename() {
		if (file != null)
			return file.getName();
		if (menuName != null && !menuName.equals("")) {
			String result = menuName;
			result = result.replaceAll(" ", "_");
			Pattern illegalChars = Pattern.compile("[^\\p{Alnum}_-]");
			Matcher match = illegalChars.matcher(result);
			result = match.replaceAll("");
			if (!result.equals(""))
				return result + ".em";
		}
		return "script.em";
	}

	public static ScriptMetadata getScriptMetadata(String contents) {
		ScriptMetadata metadata = new ScriptMetadata();
		Pattern p = Pattern.compile("^\\s*\\/\\*.*?\\*\\/", Pattern.DOTALL);
		Matcher m = p.matcher(contents);
		if (m.find()) {
			String comment = m.group();
			p = Pattern.compile("Menu:\\s*((\\p{Graph}| )+)", Pattern.DOTALL);
			m = p.matcher(comment);
			if (m.find()) {
				metadata.setMenuName(m.group(1));
			}
			p = Pattern.compile("Scope:\\s*((\\p{Graph}| )+)", Pattern.DOTALL);
			m = p.matcher(comment);
			if (m.find()) {
				metadata.setScopeName(m.group(1));
			}
		} else {
			// no meta-data comment - do nothing
		}
		return metadata;
	}
}
