/**
 * Copyright (c) 2005-2006 Aptana, Inc.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html. If redistributing this code,
 * this entire header must remain intact.
 */
package org.eclipse.eclipsemonkey.lang.javascript;

import org.eclipse.swt.SWT;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.console.ConsolePlugin;
import org.eclipse.ui.console.IConsole;
import org.eclipse.ui.console.MessageConsoleStream;
import org.mozilla.javascript.Context;
import org.mozilla.javascript.ScriptableObject;

public class JavaScriptGlobal extends ScriptableObject
{
	private static final long serialVersionUID = -8969608471837413334L;

	private static JavaScriptConsole _console;
	private static MessageConsoleStream _consoleStream;
	
	private JavaScriptPrintStream _err;
	
	/*
	 * Constructor
	 */
	public JavaScriptGlobal(Context cx)
	{
		// create unsealed standard objects
		cx.initStandardObjects(this, false);
		
		this._err = new JavaScriptPrintStream(this, System.err);
	
		MessageConsoleStream stream = getConsoleStream();
		
		this.defineProperty("err", _err, READONLY | PERMANENT); //$NON-NLS-1$
		this.defineProperty("out", stream, READONLY | PERMANENT); //$NON-NLS-1$
	}
	
	/*
	 * Methods
	 */
	
	/**
	 * initConsole
	 */
	private static MessageConsoleStream getConsoleStream()
	{
		if(_console == null)
		{
			_console = new JavaScriptConsole("Scripting Console", null); //$NON-NLS-1$
			_consoleStream = _console.newMessageStream();
			
			PlatformUI.getWorkbench().getDisplay().syncExec(new Runnable()
				{
					public void run()
					{
						_consoleStream.setColor(PlatformUI.getWorkbench().getDisplay().getSystemColor(SWT.COLOR_BLUE));
					}
				}
			);
			
			ConsolePlugin.getDefault().getConsoleManager().addConsoles(new IConsole[] { _console });
			_consoleStream.println("Eclipse Monkey JavaScript Console Started");
		}
		
		return _consoleStream;
	}
	
	public String getClassName()
	{
		return "JavaScriptGlobal";
	}
	
}
